@@ -462,10 +462,10 @@ class GetJson():
             return(command_output)
 
 @click.command()
-@click.option('--hostname', prompt='Hostname', help='Hostname of device - must match the device', required=True)
-@click.option('--os', prompt='OS', type=click.Choice(['ios', 'iosxe', 'iosxr', 'nxos'], case_sensitive=True), help='OS of device - must match the device', required=True)
-@click.option('--username', prompt='Username', help='Username', required=True)
-@click.option('--password', prompt=True, hide_input=True, help="User Password", required=True)
+@click.option('--hostname', prompt='Hostname', help='Hostname of device - must match the device', required=True, envvar="HOSTNAME")
+@click.option('--os', prompt='OS', type=click.Choice(['ios', 'iosxe', 'iosxr', 'nxos'], case_sensitive=True), help='OS of device - must match the device', required=True, envvar="OS")
+@click.option('--username', prompt='Username', help='Username', required=True, envvar="USERNAME")
+@click.option('--password', prompt=True, hide_input=True, help="User Password", required=True, envvar="PASSWORD")
 @click.option('--command', prompt='Command', help='A valid pyATS Learn Function (i.e. ospf) or valid CLI Show Command (i.e. "show ip interface brief")', required=True)
 @click.option('--filetype', prompt='Filetype', type=click.Choice(['none','json','yaml','html','csv','markdown','pdf','svg','graph','mindmap','flowchart','class','state','relationship','piechart','all'], case_sensitive=True), help='Filetype to output captured network state to', required=False, default='none')
 @click.option('--from_email', help='Email address to send output from', required=False, default='none')
